@@ -1,8 +1,6 @@
 #![cfg(feature = "full")]
 
-use crate::transaction::TransactionError;
-use std::io;
-use thiserror::Error;
+use {crate::transaction::TransactionError, std::io, thiserror::Error};
 
 #[derive(Debug, Error)]
 pub enum TransportError {
